Module boxes

Module boxes 

MP4 box structures and parsers.

Structs

MdhdBoxsub-vtt
Media Header Box (mdhd) - declares media-independent metadata and information.
SchmBoxdecrypt-cenc
Scheme Type Box (schm) - identifies the protection scheme.
SencBoxdecrypt-cenc
Sample Encryption Box (senc) - contains initialization vectors and subsample maps for all samples in a movie fragment.
SencSampledecrypt-cenc
Encryption parameters for a single media sample.
SencSubsampledecrypt-cenc
A subsample encryption entry, dividing a sample into clear (unencrypted) and encrypted bytes.
SidxBoxsidx
Segment Index Box (sidx) - provides index information for media subsegments.
SidxRangesidx
A byte range for a subsegment or media fragment indexed by the sidx box.
TencBoxdecrypt-cenc
Track Encryption Box (tenc) - default encryption parameters for a track.
TfdtBoxsub-vtt
Track Fragment Base Media Decode Time Box (tfdt) - absolute decode time of the first sample.
TfhdBoxdecrypt-cenc or sub-vtt
Track Fragment Header Box (tfhd) - provides default parameters for a track fragment.
TrunBoxdecrypt-cenc or sub-vtt
Track Fragment Run Box (trun) - provides details for each sample in a movie fragment.
TrunSampledecrypt-cenc or sub-vtt
Sample data entry within a track fragment run.