MdhdBox

Struct MdhdBox 

pub struct MdhdBox {
    pub timescale: u32,
    pub language: String,
}
Available on crate feature sub-vtt only.
Media Header Box (mdhd) - declares media-independent metadata and information.

The Media Header Box contains the overall information and media-independent metadata about the media within a track.

Fields

timescale: u32

The time-scale for this media. This is the number of time units that pass in one second.

language: String

The ISO 639-2/T 3-character language code for this media (e.g., “und”, “eng”).

Implementations

Source

impl MdhdBox

pub fn new(box_: &mut ParsedBox<'_>) -> Result<Self>

Parses a mdhd box from a ParsedBox.

This method parses the creation time, modification time, timescale, duration, and language from the box payload according to the box version (0 or 1).