pub struct SidxBox {
pub ranges: Vec<SidxRange>,
}Available on crate feature
sidx only.Expand description
Segment Index Box (sidx) - provides index information for media subsegments.
This box defines the subsegment structure, mapping them to specific byte ranges inside the media container.
Fields
ranges: Vec<SidxRange>The list of byte ranges for the indexed subsegments.
Implementations