TfdtBox

Struct TfdtBox 

pub struct TfdtBox {
    pub base_media_decode_time: u64,
}
Available on crate feature sub-vtt only.
Track Fragment Base Media Decode Time Box (tfdt) - absolute decode time of the first sample.

This box provides the absolute decode time, measured on the media timeline, of the first sample in decode order in the track fragment.

Fields

base_media_decode_time: u64

The absolute decode time, measured on the media timeline, of the first sample in decode order in the track fragment.

Implementations

Source

impl TfdtBox

pub fn new(box_: &mut ParsedBox<'_>) -> Result<Self>

Parses a tfdt box from a ParsedBox.