pub struct TfhdBox {
pub track_id: u32,
pub default_sample_duration: Option<u32>,
pub default_sample_size: Option<u32>,
pub base_data_offset: Option<u64>,
}Available on crate features
decrypt-cenc or sub-vtt only.Expand description
Track Fragment Header Box (tfhd) - provides default parameters for a track fragment.
The track fragment header specifies the track ID and can define overrides for sample parameters such as duration, size, and data offset.
Fields
track_id: u32An integer that uniquely identifies this track over the entire lifetime of this presentation.
default_sample_duration: Option<u32>If specified via flags, this overrides the default sample duration in the Track Extends Box for this fragment.
default_sample_size: Option<u32>If specified via flags, this overrides the default sample size in the Track Extends Box for this fragment.
base_data_offset: Option<u64>If specified via flags, this indicates the base data offset.
Implementations