pub struct TrunBox {
pub sample_count: u32,
pub sample_data: Vec<TrunSample>,
pub data_offset: Option<u32>,
}Available on crate features
decrypt-cenc or sub-vtt only.Expand description
Track Fragment Run Box (trun) - provides details for each sample in a movie fragment.
Fields
sample_count: u32The number of samples being added in this run.
sample_data: Vec<TrunSample>An array containing data for each sample in the run.
data_offset: Option<u32>If specified via flags, this indicates the offset of the first sample’s data in bytes.
Implementations