sample_description

Function sample_description 

pub fn sample_description(box_: ParsedBox<'_>) -> Result<(), Error>
A callback that tells the Mp4 parser to treat the body of a box as a sample description. A sample description box has a fixed number of children. The number of children is represented by a 4 byte unsigned integer. Each child is a box.