pub fn visual_sample_entry(box_: ParsedBox<'_>) -> Result<(), Error>Expand description
A callback that tells the Mp4 parser to treat the body of a box as a visual sample entry. A visual sample entry has some fixed-sized fields describing the video codec parameters, followed by an arbitrary number of appended children. Each child is a box.