macro_rules! bail {
($($arg:tt)*) => { ... };
}Expand description
Early-returns with an Error::Other variant.
This macro accepts the same format arguments as format!.
macro_rules! bail {
($($arg:tt)*) => { ... };
}Early-returns with an Error::Other variant.
This macro accepts the same format arguments as format!.