pub struct Mp4Parser { /* private fields */ }Expand description
A parser for extracting structure and metadata from MP4 files.
Implementations
Sourceimpl Mp4Parser
impl Mp4Parser
pub fn new() -> Self
Sourcepub fn base_box(
self,
type_: &str,
definition: impl Fn(ParsedBox<'_>) -> Result<(), Error> + 'static,
) -> Self
pub fn base_box( self, type_: &str, definition: impl Fn(ParsedBox<'_>) -> Result<(), Error> + 'static, ) -> Self
Registers a basic box type with its associated parser callback.
Sourcepub fn full_box(
self,
type_: &str,
definition: impl Fn(ParsedBox<'_>) -> Result<(), Error> + 'static,
) -> Self
pub fn full_box( self, type_: &str, definition: impl Fn(ParsedBox<'_>) -> Result<(), Error> + 'static, ) -> Self
Registers a full box type with its associated parser callback.
Sourcepub fn parse(
&mut self,
data: &[u8],
partial_okay: bool,
stop_on_partial: bool,
) -> Result<(), Error>
pub fn parse( &mut self, data: &[u8], partial_okay: bool, stop_on_partial: bool, ) -> Result<(), Error>
Parses the given MP4 data buffer using the registered callbacks.
Arguments
partial_okay- If true, allows parsing box structures even if payloads are incomplete.stop_on_partial- If true, halts reading when an incomplete box is encountered.