MP4 box structures and parsers.
Structs
- MdhdBox
sub-vtt - Media Header Box (mdhd) - declares media-independent metadata and information.
- SchmBox
decrypt-cenc - Scheme Type Box (schm) - identifies the protection scheme.
- SencBox
decrypt-cenc - Sample Encryption Box (senc) - contains initialization vectors and subsample maps for all samples in a movie fragment.
- Senc
Sample decrypt-cenc - Encryption parameters for a single media sample.
- Senc
Subsample decrypt-cenc - A subsample encryption entry, dividing a sample into clear (unencrypted) and encrypted bytes.
- SidxBox
sidx - Segment Index Box (sidx) - provides index information for media subsegments.
- Sidx
Range sidx - A byte range for a subsegment or media fragment indexed by the
sidxbox. - TencBox
decrypt-cenc - Track Encryption Box (tenc) - default encryption parameters for a track.
- TfdtBox
sub-vtt - Track Fragment Base Media Decode Time Box (tfdt) - absolute decode time of the first sample.
- TfhdBox
decrypt-cencorsub-vtt - Track Fragment Header Box (tfhd) - provides default parameters for a track fragment.
- TrunBox
decrypt-cencorsub-vtt - Track Fragment Run Box (trun) - provides details for each sample in a movie fragment.
- Trun
Sample decrypt-cencorsub-vtt - Sample data entry within a track fragment run.