pub struct MdhdBox {
pub timescale: u32,
pub language: String,
}Available on crate feature
sub-vtt only.Expand description
Media Header Box (mdhd) - declares media-independent metadata and information.
The Media Header Box contains the overall information and media-independent metadata about the media within a track.
Fields
timescale: u32The time-scale for this media. This is the number of time units that pass in one second.
language: StringThe ISO 639-2/T 3-character language code for this media (e.g., “und”, “eng”).
Implementations