pub fn audio_sample_entry(box_: ParsedBox<'_>) -> Result<(), Error>Expand description
A callback that tells the Mp4 parser to treat the body of a box as a audio sample entry. A audio sample entry has some fixed-sized fields describing the audio codec parameters, followed by an arbitrary number of ppended children. Each child is a box.